@@ -201,7 +201,7 @@ gcm_prefs_file_chooser_get_icc_profile (CcColorPanel *prefs)
   dialog = gtk_file_chooser_dialog_new (_("Select ICC Profile File"), window,
                                         GTK_FILE_CHOOSER_ACTION_OPEN,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                        _("Import"), GTK_RESPONSE_ACCEPT,
+                                        _("_Import"), GTK_RESPONSE_ACCEPT,
                                         NULL);
   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(dialog), g_get_home_dir ());
   gtk_file_chooser_set_create_folders (GTK_FILE_CHOOSER(dialog), FALSE);
@@ -252,6 +252,7 @@ gcm_prefs_calibrate_cb (GtkWidget *widget, CcColorPanel *prefs)
   g_ptr_array_add (argv, g_strdup (cd_device_get_id (priv->current_device)));
   g_ptr_array_add (argv, g_strdup ("--parent-window"));
   g_ptr_array_add (argv, g_strdup_printf ("%i", xid));
+  g_ptr_array_add (argv, NULL);
   ret = g_spawn_async (NULL, (gchar**) argv->pdata, NULL, 0,
                        NULL, NULL, NULL, &error);
   if (!ret)
@@ -350,6 +351,14 @@ gcm_prefs_combo_sort_func_cb (GtkTreeModel *model,
   return retval;
 }
 
+static gboolean
+gcm_prefs_combo_set_default_cb (gpointer user_data)
+{
+  GtkWidget *widget = GTK_WIDGET (user_data);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+  return FALSE;
+}
+
 static void
 gcm_prefs_add_profiles_suitable_for_devices (CcColorPanel *prefs,
                                              GtkWidget *widget,
@@ -424,7 +433,7 @@ gcm_prefs_add_profiles_suitable_for_devices (CcColorPanel *prefs,
 #if CD_CHECK_VERSION(0,1,12)
   gcm_prefs_combobox_add_profile (widget, NULL, GCM_PREFS_ENTRY_TYPE_IMPORT, NULL);
 #endif
-  gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+  g_idle_add (gcm_prefs_combo_set_default_cb, widget);
 out:
   if (profile_array != NULL)
     g_ptr_array_unref (profile_array);
@@ -1110,6 +1119,19 @@ gcm_prefs_profile_combo_changed_cb (GtkWidget *widget,
         {
           g_warning ("failed to get ICC file");
           gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+
+          /* if we've got no other existing profiles to choose, then
+           * just close the assign dialog */
+          gtk_combo_box_get_active_iter (GTK_COMBO_BOX(widget), &iter);
+          gtk_tree_model_get (model, &iter,
+                              GCM_PREFS_COMBO_COLUMN_TYPE, &entry_type,
+                              -1);
+          if (entry_type == GCM_PREFS_ENTRY_TYPE_IMPORT)
+            {
+              widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
+                                                           "dialog_assign"));
+              gtk_widget_hide (widget);
+            }
           goto out;
         }
 
