@@ -44,6 +44,8 @@ G_DEFINE_TYPE (GnomeControlCenter, gnome_control_center, CC_TYPE_SHELL)
 
 #define W(b,x) GTK_WIDGET (gtk_builder_get_object (b, x))
 
+#define MIN_ICON_VIEW_HEIGHT 50
+
 enum
 {
   OVERVIEW_PAGE,
@@ -63,7 +65,6 @@ struct _GnomeControlCenterPrivate
   GtkWidget  *lock_button;
 
   GMenuTree  *menu_tree;
-  char       *desktop_files_dir;
   GtkListStore *store;
   GHashTable *category_views;
 
@@ -179,7 +180,7 @@ activate_panel (GnomeControlCenter *shell,
 
           /* set the scrolled window small so that it doesn't force
              the window to be larger than this panel */
-          gtk_scrolled_window_set_min_content_height (GTK_SCROLLED_WINDOW (priv->scrolled_window), 50);
+          gtk_scrolled_window_set_min_content_height (GTK_SCROLLED_WINDOW (priv->scrolled_window), MIN_ICON_VIEW_HEIGHT);
 
           /* resize to the preferred size of the panel */
           gtk_widget_set_size_request (priv->window, FIXED_WIDTH, -1);
@@ -658,19 +659,6 @@ maybe_add_category_view (GnomeControlCenter *shell,
   g_hash_table_insert (shell->priv->category_views, g_strdup (name), categoryview);
 }
 
-static gboolean
-item_is_in_dir (GnomeControlCenter *shell,
-		GMenuTreeEntry *item)
-{
-  const char *path;
-
-  path = gmenu_tree_entry_get_desktop_file_path (item);
-
-  if (g_str_has_prefix (path, shell->priv->desktop_files_dir))
-    return TRUE;
-  return FALSE;
-}
-
 static void
 reload_menu (GnomeControlCenter *shell)
 {
@@ -712,12 +700,9 @@ reload_menu (GnomeControlCenter *shell)
               if (sub_next_type == GMENU_TREE_ITEM_ENTRY)
                 {
                   GMenuTreeEntry *item = gmenu_tree_iter_get_entry (sub_iter);
-                  if (item_is_in_dir (shell, item))
-                    {
-                      cc_shell_model_add_item (CC_SHELL_MODEL (shell->priv->store),
-                                               dir_name,
-                                               item);
-                    }
+                  cc_shell_model_add_item (CC_SHELL_MODEL (shell->priv->store),
+                                           dir_name,
+                                           item);
                   gmenu_tree_item_unref (item);
                 }
             }
@@ -742,7 +727,6 @@ static void
 setup_model (GnomeControlCenter *shell)
 {
   GnomeControlCenterPrivate *priv = shell->priv;
-  GFile *file;
 
   gtk_container_set_border_width (GTK_CONTAINER (shell->priv->main_vbox), 10);
   gtk_container_set_focus_vadjustment (GTK_CONTAINER (shell->priv->main_vbox),
@@ -752,11 +736,6 @@ setup_model (GnomeControlCenter *shell)
   priv->category_views = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
   priv->menu_tree = gmenu_tree_new_for_path (MENUDIR "/gnomecc.menu", 0);
 
-  /* Normalise the file path, to avoid repeat slashes */
-  file = g_file_new_for_path (DESKTOP_FILES_DIR);
-  priv->desktop_files_dir = g_file_get_path (file);
-  g_object_unref (file);
-
   reload_menu (shell);
 
   g_signal_connect (priv->menu_tree, "changed", G_CALLBACK (on_menu_changed), shell);
@@ -987,12 +966,6 @@ gnome_control_center_finalize (GObject *object)
       g_object_unref (priv->menu_tree);
     }
 
-  if (priv->desktop_files_dir)
-    {
-      g_free (priv->desktop_files_dir);
-      priv->desktop_files_dir = NULL;
-    }
-
   if (priv->category_views)
     {
       g_hash_table_destroy (priv->category_views);
@@ -1057,7 +1030,7 @@ on_window_size_allocate (GtkWidget          *widget,
     }
   else
     {
-      height = 50;
+      height = MIN_ICON_VIEW_HEIGHT;
     }
 
   if (gtk_scrolled_window_get_min_content_height (GTK_SCROLLED_WINDOW (self->priv->scrolled_window)) != height)
